@@ -156,6 +156,5 @@ class Instrument:
 
 	def stop_playing_notes(self):
 		if not self.no_fluidsynth:
-			fluidsynth.stop_NoteContainer(self.playing,
-				self.last_chan)
+			fluidsynth.stop_NoteContainer(self.playing, self.last_chan)
 		self.playing = []
